@@ -95,7 +95,9 @@ static EelEnumerationEntry file_size_enum_entries[] = {
 	{ "5242880",	    N_("5 MB"),		5242880 },
 	{ "10485760",	    N_("10 MB"),	10485760 },
 	{ "104857600",	    N_("100 MB"),	104857600 },
-	{ "1073741824",     N_("1 GB"),         1073741824 }
+	{ "1073741824",     N_("1 GB"),         1073741824 },
+	{ "2147483648",     N_("2 GB"),         2147483648U },
+ 	{ "4294967295",     N_("4 GB"),         4294967295U }
 };
 
 static EelEnumerationEntry click_policy_enum_entries[] = {
@@ -278,6 +280,10 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "executable_text_activation"
 	},
+	{ NAUTILUS_PREFERENCES_INSTALL_MIME_ACTIVATION,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (TRUE)
+	},
 	{ NAUTILUS_PREFERENCES_THEME,
 	  PREFERENCE_STRING,
 	  "default"
