@@ -462,16 +462,16 @@ nautilus_link_get_link_icon_from_desktop (GKeyFile *key_file)
 	}
 
 	type = g_key_file_get_string (key_file, MAIN_GROUP, "Type", NULL);
-	if (strcmp (type, "Application") == 0) {
+	if (g_strcmp0 (type, "Application") == 0) {
 		icon = g_strdup ("gnome-fs-executable");
-	} else if (strcmp (type, "Link") == 0) {
+	} else if (g_strcmp0 (type, "Link") == 0) {
 		icon = g_strdup ("gnome-dev-symlink");
-	} else if (strcmp (type, "FSDevice") == 0) {
+	} else if (g_strcmp0 (type, "FSDevice") == 0) {
 		icon = g_strdup ("gnome-dev-harddisk");
-	} else if (strcmp (type, "Directory") == 0) {
+	} else if (g_strcmp0 (type, "Directory") == 0) {
 		icon = g_strdup (NAUTILUS_ICON_FOLDER);
-	} else if (strcmp (type, "Service") == 0 ||
-		   strcmp (type, "ServiceType") == 0) {
+	} else if (g_strcmp0 (type, "Service") == 0 ||
+		   g_strcmp0 (type, "ServiceType") == 0) {
 		icon = g_strdup ("gnome-fs-web");
 	} else {
 		icon = g_strdup ("gnome-fs-regular");
@@ -534,8 +534,7 @@ nautilus_link_get_link_info_given_file_contents (const char  *file_contents,
 
 	*is_launcher = FALSE;
 	type = g_key_file_get_string (key_file, MAIN_GROUP, "Type", NULL);
-	if (type != NULL &&
-	    strcmp (type, "Application") == 0 &&
+	if (g_strcmp0 (type, "Application") == 0 &&
 	    g_key_file_has_key (key_file, MAIN_GROUP, "Exec", NULL)) {
 		*is_launcher = TRUE;
 	}
