@@ -36,9 +36,7 @@
 #include <eel/eel-gnome-extensions.h>
 #include <libnautilus-private/nautilus-undo-signal-handlers.h>
 #include <gtk/gtk.h>
-#include <gnome.h>
-#include <libgnomeui/gnome-help.h>
-#include <glade/glade.h>
+#include <gdk/gdkkeysyms.h>
 
 /* Static variables to keep track of window state. If there were
  * more than one bookmark-editing window, these would be struct or
@@ -147,9 +145,9 @@ nautilus_bookmarks_window_response_callback (GtkDialog *dialog,
 	if (response_id == GTK_RESPONSE_HELP) {
 		GError *error = NULL;
 
-		gnome_help_display_desktop_on_screen (
-			NULL, "user-guide", "user-guide.xml", "gosnautilus-36",
-			gtk_window_get_screen (GTK_WINDOW (dialog)), &error);
+		gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (dialog)),
+			      "ghelp:user-guide#gosnautilus-36",
+			      gtk_get_current_event_time (), &error);
 
 		if (error) {
 			GtkWidget *err_dialog;
@@ -251,21 +249,22 @@ create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_sourc
 	GtkWidget         *window;
 	GtkTreeViewColumn *col;
 	GtkCellRenderer   *rend;
-	GladeXML          *gui;
+	GtkBuilder        *builder;
 
 	bookmarks = list;
 
-	gui = eel_glade_get_file (GLADEDIR "/nautilus-bookmarks-window.glade",
-				  NULL, NULL,
-				  "bookmarks_dialog", &window,
-				  "bookmark_tree_view", &bookmark_list_widget,
-				  "bookmark_delete_button", &remove_button,
-                                  "bookmark_jump_button", &jump_button,
-				  NULL);
-	if (!gui) {
+	builder = gtk_builder_new ();
+	if (!gtk_builder_add_from_file (builder,
+					UIDIR  "/nautilus-bookmarks-window.ui",
+					NULL)) {
 		return NULL;
 	}
 
+	window = (GtkWidget *)gtk_builder_get_object (builder, "bookmarks_dialog");
+	bookmark_list_widget = (GtkTreeView *)gtk_builder_get_object (builder, "bookmark_tree_view");
+	remove_button = (GtkWidget *)gtk_builder_get_object (builder, "bookmark_delete_button");
+	jump_button = (GtkWidget *)gtk_builder_get_object (builder, "bookmark_jump_button");
+
 	application = NAUTILUS_WINDOW (undo_manager_source)->application;
 
 	if (NAUTILUS_IS_NAVIGATION_WINDOW (undo_manager_source)) {
@@ -283,7 +282,7 @@ create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_sourc
 	g_object_weak_ref (G_OBJECT (undo_manager_source), edit_bookmarks_dialog_reset_signals, 
 			   undo_manager_source);
 	
-	bookmark_list_widget = GTK_TREE_VIEW (glade_xml_get_widget (gui, "bookmark_tree_view"));
+	bookmark_list_widget = GTK_TREE_VIEW (gtk_builder_get_object (builder, "bookmark_tree_view"));
 
 	rend = gtk_cell_renderer_pixbuf_new ();
 	col = gtk_tree_view_column_new_with_attributes ("Icon", 
@@ -318,22 +317,22 @@ create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_sourc
 	name_field = nautilus_entry_new ();
 	
 	gtk_widget_show (name_field);
-	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (gui, "bookmark_name_placeholder")),
+	gtk_box_pack_start (GTK_BOX (gtk_builder_get_object (builder, "bookmark_name_placeholder")),
 			    name_field, TRUE, TRUE, 0);
 	nautilus_undo_editable_set_undo_key (GTK_EDITABLE (name_field), TRUE);
 	
 	gtk_label_set_mnemonic_widget (
-		GTK_LABEL (glade_xml_get_widget (gui, "bookmark_name_label")),
+		GTK_LABEL (gtk_builder_get_object (builder, "bookmark_name_label")),
 		name_field);
 
 	uri_field = nautilus_entry_new ();
 	gtk_widget_show (uri_field);
-	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (gui, "bookmark_location_placeholder")),
+	gtk_box_pack_start (GTK_BOX (gtk_builder_get_object (builder, "bookmark_location_placeholder")),
 			    uri_field, TRUE, TRUE, 0);
 	nautilus_undo_editable_set_undo_key (GTK_EDITABLE (uri_field), TRUE);
 
 	gtk_label_set_mnemonic_widget (
-		GTK_LABEL (glade_xml_get_widget (gui, "bookmark_location_label")),
+		GTK_LABEL (gtk_builder_get_object (builder, "bookmark_location_label")),
 		uri_field);
 
 	bookmark_list_changed_signal_id =
@@ -395,7 +394,7 @@ create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_sourc
 	/* Fill in list widget with bookmarks, must be after signals are wired up. */
 	repopulate();
 
-	g_object_unref (G_OBJECT (gui));
+	g_object_unref (builder);
 	
 	return GTK_WINDOW (window);
 }
@@ -761,8 +760,9 @@ on_selection_changed (GtkTreeSelection *treeselection,
 		      gpointer user_data)
 {
 	NautilusBookmark *selected;
-	char *name = NULL, *uri = NULL;
-	
+	char *name = NULL, *entry_text = NULL;
+	GFile *location;
+
 	g_assert (GTK_IS_ENTRY (name_field));
 	g_assert (GTK_IS_ENTRY (uri_field));
 
@@ -770,7 +770,10 @@ on_selection_changed (GtkTreeSelection *treeselection,
 
 	if (selected) {
 		name = nautilus_bookmark_get_name (selected);
-		uri = nautilus_bookmark_get_uri (selected);
+		location = nautilus_bookmark_get_location (selected);
+		entry_text = g_file_get_parse_name (location);
+
+		g_object_unref (location);
 	}
 	
 	/* Set the sensitivity of widgets that require a selection */
@@ -786,14 +789,14 @@ on_selection_changed (GtkTreeSelection *treeselection,
 
 	g_signal_handler_block (uri_field, uri_field_changed_signal_id);
 	nautilus_entry_set_text (NAUTILUS_ENTRY (uri_field),
-				 uri ? uri : "");
+				 entry_text ? entry_text : "");
 	g_signal_handler_unblock (uri_field, uri_field_changed_signal_id);
 
 	text_changed = FALSE;
 	name_text_changed = FALSE;
 
 	g_free (name);
-	g_free (uri);
+	g_free (entry_text);
 }
 
 
@@ -811,7 +814,8 @@ update_bookmark_from_text (void)
 		g_assert (GTK_IS_ENTRY (name_field));
 		g_assert (GTK_IS_ENTRY (uri_field));
 
-		location = g_file_new_for_uri (gtk_entry_get_text (GTK_ENTRY (uri_field)));
+		location = g_file_parse_name 
+			(gtk_entry_get_text (GTK_ENTRY (uri_field)));
 		
 		bookmark = nautilus_bookmark_new_with_icon (location, gtk_entry_get_text (GTK_ENTRY (name_field)),
 							    name_text_changed, NULL);
